#
# spec file for package httperf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           httperf
Version:        0.9.0+git.20201206
Release:        2.1
Summary:        A tool for measuring web server performance
License:        SUSE-GPL-2.0+-with-openssl-exception
URL:            https://github.com/httperf/httperf
Source0:        %{name}-%{version}.tar.gz
# build with gcc15
Patch0:         httperf-gcc15.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)

%description
httperf is a tool for measuring web server performance. It provides a
flexible facility for generating various HTTP workloads and for measuring
server performance.

%prep
%autosetup -p1
chmod -x AUTHORS ChangeLog NEWS README.md TODO

%build
mkdir m4
autoreconf -fiv
%configure
%make_build

%install
%make_install

%files
%doc AUTHORS ChangeLog NEWS README.md TODO
%{_bindir}/httperf
%{_mandir}/man1/httperf.1%{?ext_man}
%{_mandir}/man1/idleconn.1%{?ext_man}

%changelog
* Wed Mar  5 2025 pgajdos@suse.com
- added patches
  fix build with gcc15
  + httperf-gcc15.patch
* Wed Dec 11 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.9.0+git.20201206:
  * [httperf] Fix Issue #43 - update config / build instructions.
  * The installation steps given in current README fail. I had to follow steps given in the comments of a previous Issue to build it properly. I am including those steps in README, as they are pretty generic and should work for everyone.
  * Fix segfault when connection is failed by using epoll(7).
  * Teach to use epoll(7) on httperf(1).
  * Use correct ifdefs for checking TLS 1.3
* Tue Oct  9 2018 Cristian Rodríguez <crrodriguez@opensuse.org>
- Only alter __DATE__ and __TIME__ values when SOURCE_DATE_EPOCH
  is not set.
* Tue Oct  9 2018 crrodriguez@opensuse.org
- Update to version 0.9.0+git.20180712:
  * Add missing 'case' statement that causes TLSv1.3 implementation to be unreachable.
  * Remove extra 'break;' that prevent SSL_CTX_set_options from being set
  * Fix a bug that ignored the --ssl-protocol parameter
  * Implement support for TLSv1.3 in OpenSSL >= 1.1.1
  * Implement specific support for TLSv1.2
  * Implement specific support for TLSv1.1
  * Make TLSv1 use TLSv1.0 specifically to prevent ambiguity with TLSv1.1, TLSv1.2, TLSv1.3
  * Missing include (for memset(), strerror()).
  * Stray line feed in fqdname causes --add-header and --add-header-file header records to be ignored by server.
  * Add support for PROPFIND and REPORT in wsesslog
* Mon Dec  4 2017 mpluskal@suse.com
- Explicitly BuildRequire libopenssl-1_0_0-devel until OpenSSL
  1.1.x support is ported
* Mon Dec  4 2017 mpluskal@suse.com
- Update to version 0.9.0+git.20170724:
  * make it compile with SSL 1.1.0
  * fix typo in manpage
  * Added a contrib dir and idleconn manpage source
  * Adding idleconn manpage
  * Restore the original --server and --server_name options.
  * Change --server to --servers.
  * Style changes.
  * Fix building when OpenSSL was compiled -nossl2  or -noss3
  * added ACLOCAL_AMFLAGS to include m4
  * Add AC_CONFIG_MACRO_DIR
* Wed Aug 17 2016 mpluskal@suse.com
- Fix building on SLE-11
* Wed Apr 27 2016 mpluskal@suse.com
- Update to version 0.9.0+git.20160311:
  * Add AC_CONFIG_MACRO_DIR
  * added ACLOCAL_AMFLAGS to include m4
  * apply https://github.com/httperf/httperf/issues/8 patch from rowan.li...@gmail.com
  * Fix building when OpenSSL was compiled -nossl2  or -noss3
  * Style changes.
  * Change --server to --servers.
  * Restore the original --server and --server_name options.
  * Adding idleconn manpage
  * Added a contrib dir and idleconn manpage source
- Add _service and switch to version from git (stable release is
  more than 8 years old)
* Wed Apr  8 2015 mpluskal@suse.com
- Update license
* Mon Apr  6 2015 mpluskal@suse.com
- Initial package
